@@ -1,16 +1,12 @@
 use std::env;
 
 fn main() {
-    // HAS
     match env::var("DEP_OPENSSL_VERSION") {
         Ok(ref v) if v == "101" => {
         }
-        Ok(ref v) if v == "102" => {
+        Ok(ref v) if v >= &"102".to_string() => {
             println!("cargo:rustc-cfg=has_alpn");
-        }
-        Ok(ref v) if v == "110" => {
-            println!("cargo:rustc-cfg=has_alpn");
-        }
-        _ => panic!("Unable to detect OpenSSL version"),
+        }        
+        _ => panic!("tls-api-openssl: Unable to detect OpenSSL version"),
     }
 }
